# Fabrizio Gilardi (2010), "Who learns from what in policy diffusion processes?" AJPS 54(3)
# Replication of Appendix 3

library(lme4)

d <- read.table("data.csv", sep=",", header=TRUE)


# Model A1

d1 <- d[d$samecountry==0 & d$uerrd_b< 0, ]
d1$part_a <- (d1$rightc_a + d1$centc_a - d1$leftc_a)/100
d1$part_b <- (d1$rightc_b + d1$centc_b - d1$leftc_b)/100

m.A1 <- lmer(imit ~ part_a + I(abs(part_a - part_b)) + uerrl_a + I(abs(uerrl_a-uerrm_b)) + ue_b + vote_b  + part_a*vote_b + part_a*ue_b +  samereg + popdiff + uer_a + polconiii_a + ncuts_a + (1 | countryn_a) + (1 | countryn_b) + (1 | year), data=d1, family='binomial')

summary(m.A1)


# Model A2

d2 <- d[d$samecountry==0 & d$uerrd_b< 0, ]
d2$part_a <- (d2$rightc_a - d2$centc_a - d2$leftc_a)/100
d2$part_b <- (d2$rightc_b - d2$centc_b - d2$leftc_b)/100

m.A2 <- lmer(imit ~ part_a + I(abs(part_a - part_b)) + uerrl_a + I(abs(uerrl_a-uerrm_b)) + ue_b + vote_b  + part_a*vote_b + part_a*ue_b +  samereg + popdiff + uer_a + polconiii_a + ncuts_a + (1 | countryn_a) + (1 | countryn_b) + (1 | year), data=d2, family='binomial')

summary(m.A2)


# Model A3

d3 <- d[d$samecountry==0 & d$uerrd_b< 0, ]
d3$part_a <- (d3$rightgs_a - d3$leftgs_a)/100
d3$part_b <- (d3$rightgs_b - d3$leftgs_b)/100

m.A3 <- lmer(imit ~ part_a + I(abs(part_a - part_b)) + uerrl_a + I(abs(uerrl_a-uerrm_b)) + ue_b + vote_b  + part_a*vote_b + part_a*ue_b +  samereg + popdiff + uer_a + polconiii_a + ncuts_a + (1 | countryn_a) + (1 | countryn_b) + (1 | year), data=d3, family='binomial')

summary(m.A3)


# Model A4

d4 <- d[d$samecountry==0 & d$uerrd_b< 0, ]
d4$part_a <- (d4$rightc_a - d4$leftc_a)/100
d4$part_b <- (d4$rightc_b - d4$leftc_b)/100

m.A4 <- lmer(imit ~ part_a + I(abs(part_a - part_b)) + uerrl_a + I(abs(uerrl_a-uerrm_b)) + ue_p_b + vote_p_b  + part_a*vote_p_b + part_a*ue_p_b +  samereg + popdiff + uer_a + polconiii_a + ncuts_a + (1 | countryn_a) + (1 | countryn_b) + (1 | year), data=d4, family='binomial')

summary(m.A4)


# Model A5

d5 <- d[d$samecountry==0 & d$uerrd_b< 0, ]
d5$part_a <- (d5$rightc_a - d5$leftc_a)/100
d5$part_b <- (d5$rightc_b - d5$leftc_b)/100

m.A5 <- lmer(imit ~ part_a + I(abs(part_a - part_b)) + uerrl_a + I(abs(uerrl_a-uerrm_b)) + ue_w_b + vote_w_b  + part_a*vote_w_b + part_a*ue_w_b +  samereg + popdiff + uer_a + polconiii_a + ncuts_a + (1 | countryn_a) + (1 | countryn_b) +(1 | year), data=d5, family='binomial')

summary(m.A5)


# Model A6

d6 <- d[d$samecountry==0 & d$uerrd_b< 0, ]
d6$part_a <- (d6$rightc_a - d6$leftc_a)/100
d6$part_b <- (d6$rightc_b - d6$leftc_b)/100

m.A6 <- lmer(imit ~ part_a + I(abs(part_a - part_b)) + uerrl_a + I(abs(uerrl_a-uerrm_b)) + ue_p_w_b + vote_p_w_b  + part_a*vote_p_w_b + part_a*ue_p_w_b +  samereg + popdiff + uer_a + polconiii_a + ncuts_a + (1 | countryn_a) + (1 | countryn_b) + (1 | year), data=d6, family='binomial')

summary(m.A6)


# Model A7

d7 <- d[d$samecountry==0 & d$uerrd_b< -0.25, ]
d7$part_a <- (d7$rightc_a - d7$leftc_a)/100
d7$part_b <- (d7$rightc_b - d7$leftc_b)/100

m.A7 <- lmer(imit2 ~ part_a + I(abs(part_a - part_b)) + uerrl_a + I(abs(uerrl_a-uerrm_b)) + ue_b + vote_b  + part_a*vote_b + part_a*ue_b +  samereg + popdiff + uer_a + polconiii_a + ncuts2_a + (1 | countryn_a) + (1 | countryn_b) + (1 | year), data=d7, family='binomial')

summary(m.A7)


# Model A8

d8 <- d[d$samecountry==0 & d$uerrd_b< -0.5, ]
d8$part_a <- (d8$rightc_a - d8$leftc_a)/100
d8$part_b <- (d8$rightc_b - d8$leftc_b)/100

m.A8 <- lmer(imit3 ~ part_a + I(abs(part_a - part_b)) + uerrl_a + I(abs(uerrl_a-uerrm_b)) + ue_b + vote_b  + part_a*vote_b + part_a*ue_b +  samereg + popdiff + uer_a + polconiii_a + ncuts3_a + (1 | countryn_a) + (1 | countryn_b) + (1 | year), data=d8, family='binomial')

summary(m.A8)


# Model A9

d9 <- d[d$samecountry==0 & d$uerrd_b< -0.75, ]
d9$part_a <- (d9$rightc_a - d9$leftc_a)/100
d9$part_b <- (d9$rightc_b - d9$leftc_b)/100

m.A9 <- lmer(imit4 ~ part_a + I(abs(part_a - part_b)) + uerrl_a + I(abs(uerrl_a-uerrm_b)) + ue_b + vote_b  + part_a*vote_b + part_a*ue_b +  samereg + popdiff + uer_a + polconiii_a + ncuts4_a + (1 | countryn_a) + (1 | countryn_b) + (1 | year), data=d9, family='binomial')

summary(m.A9)


# Model A10

d10 <- d[d$samecountry==0 & d$uerrd_b< -1, ]
d10$part_a <- (d10$rightc_a - d10$leftc_a)/100
d10$part_b <- (d10$rightc_b - d10$leftc_b)/100

m.A10 <- lmer(imit5 ~ part_a + I(abs(part_a - part_b)) + uerrl_a + I(abs(uerrl_a-uerrm_b)) + ue_b + vote_b  + part_a*vote_b + part_a*ue_b +  samereg + popdiff + uer_a + polconiii_a + ncuts5_a + (1 | countryn_a) + (1 | countryn_b) + (1 | year), data=d10, family='binomial')

summary(m.A10)



